#[non_exhaustive]pub enum OS {
Show 49 variants
Aix,
Amdhsa,
Android,
Cuda,
Cygwin,
Dragonfly,
Emscripten,
Espidf,
FreeBSD,
Fuchsia,
Haiku,
HelenOS,
Hermit,
Horizon,
Hurd,
IllumOS,
iOS,
L4re,
Linux,
Lynxos178,
MacOS,
Managarm,
Motor,
NetBSD,
None,
Nto,
Nuttx,
OpenBSD,
Psp,
Psx,
Qurt,
Redox,
Rtems,
Solaris,
SolidAsp3,
TeeOS,
Trusty,
TvOS,
Uefi,
Unknown,
VexOS,
VisionOS,
Vita,
VxWorks,
Wasi,
WatchOS,
Windows,
Xous,
Zkvm,
}Expand description
target_os: Operating system of the target.
This value is closely related to the second and third element of the platform target triple, though it is not identical.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Aix
aix
Amdhsa
amdhsa
Android
android: Google’s Android mobile operating system
Cuda
cuda: CUDA parallel computing platform
Cygwin
cygwin
Dragonfly
dragonfly: DragonflyBSD
Emscripten
emscripten: The emscripten JavaScript transpiler
Espidf
espidf
FreeBSD
freebsd: The FreeBSD operating system
Fuchsia
fuchsia: Google’s next-gen Rust OS
Haiku
haiku: Haiku, an open source BeOS clone
HelenOS
helenos
Hermit
hermit: HermitCore is a novel unikernel operating system targeting a scalable and predictable runtime behavior for HPC and cloud environments
Horizon
horizon
Hurd
hurd
IllumOS
illumos: illumos is a partly free and open-source Unix operating system based on OpenSolaris
iOS
ios: Apple’s iOS mobile operating system
L4re
l4re
Linux
linux: Linux
Lynxos178
lynxos178
MacOS
macos: Apple’s Mac OS X
Managarm
managarm
Motor
motor
NetBSD
netbsd: The NetBSD operating system
None
none
Nto
nto
Nuttx
nuttx
OpenBSD
openbsd: The OpenBSD operating system
Psp
psp
Psx
psx
Qurt
qurt
Redox
redox: Redox, a Unix-like OS written in Rust
Rtems
rtems
Solaris
solaris: Oracle’s (formerly Sun) Solaris operating system
SolidAsp3
solid_asp3
TeeOS
teeos
Trusty
trusty
TvOS
tvos
Uefi
uefi
Unknown
unknown
VexOS
vexos
VisionOS
visionos
Vita
vita
VxWorks
vxworks: VxWorks is a deterministic, priority-based preemptive RTOS with low latency and minimal jitter
Wasi
wasi: The WebAssembly System Interface
WatchOS
watchos
Windows
windows: Microsoft’s Windows operating system
Xous
xous
Zkvm
zkvm