Crate platforms[−][src]
Rust platform registry: provides programmatic access to information about valid Rust platforms
This crate provides an interface to the platform data available at Rust Forge:
Re-exports
pub use platform::Platform; |
pub use platform::ALL_PLATFORMS; |
Modules
| platform |
Rust platform types |
| target |
Rust target types
Target |
Structs
| Error |
Error type |
| PlatformReq |
Platform requirements: glob-like expressions for matching Rust platforms
as identified by a "target triple", e.g. |
Enums
| Tier |
Rust platform tiers: support levels are organized into three tiers, each with a different set of guarantees. |
Constants
| TARGET_ARCH |
|
| TARGET_ENV |
|
| TARGET_OS |
|
Functions
| find |
Find a Rust platform by its "target triple", e.g. |
| guess_current |
Attempt to guess the current |