Module platform

Module platform 

Rust platforms

Structs

Platform
Rust platforms supported by mainline rustc
PlatformReq
Platform requirements: glob-like expressions for matching Rust platforms as identified by a “target triple”, e.g. i686-apple-darwin.

Enums

Tier
Rust platform tiers: support levels are organized into three tiers, each with a different set of guarantees.